==> dojo_1.6.1+dfsg.orig.tar.gz: dojo-release-1.6.1-src+dfsg/dojox/grid/enhanced/nls/fr/Filter.js <==
﻿({
	"clearFilterDialogTitle": "Effacer le filtre",
	"filterDefDialogTitle": "Filtrer",
	"ruleTitleTemplate": "Règle ${0}",
	
	"conditionEqual": "égal",
	"conditionNotEqual": "est différent de",
	"conditionLess": "est inférieur à",
	"conditionLessEqual": "inférieur ou égal",
	"conditionLarger": "est supérieur à",
	"conditionLargerEqual": "supérieur ou égal",
	"conditionContains": "contient",
	"conditionIs": "est",
	"conditionStartsWith": "commence par",
	"conditionEndWith": "se termine par",
	"conditionNotContain": "ne contient pas",
	"conditionIsNot": "n'est pas",
	"conditionNotStartWith": "ne commence pas par",
	"conditionNotEndWith": "ne se termine pas par",
	"conditionBefore": "avant",
	"conditionAfter": "après",
	"conditionRange": "plage",
	"conditionIsEmpty": "est vide",
	
	"all": "tout",
	"any": "n'importe quelle",
	"relationAll": "toutes les règles",
	"waiRelAll": "Satisfaire à toutes les règles suivantes :",
	"relationAny": "n'importe quelles règles",
	"waiRelAny": "Satisfaire à une quelconque des règles suivantes :",
	"relationMsgFront": "Satisfaire",
	"relationMsgTail": "",
	"and": "et",
	"or": "ou",
	
	"addRuleButton": "Ajouter une règle",
	"waiAddRuleButton": "Ajouter une nouvelle règle",
	"removeRuleButton": "Supprimer la règle",
	"waiRemoveRuleButtonTemplate": "Supprimer la règle ${0}",
	
	"cancelButton": "Annuler",
	"waiCancelButton": "Annuler cette boîte de dialogue",
	"clearButton": "Effacer",
	"waiClearButton": "Effacer le filtre",
	"filterButton": "Filtrer",
	"waiFilterButton": "Soumettre le filtre",
	
	"columnSelectLabel": "Colonne",
	"waiColumnSelectTemplate": "Colonne pour la règle ${0}",
	"conditionSelectLabel": "Condition",
	"waiConditionSelectTemplate": "Condition pour la règle ${0}",
	"valueBoxLabel": "Valeur",
	"waiValueBoxTemplate": "Saisir la valeur à filtrer pour la règle ${0}",
	
	"rangeTo": "à",
	"rangeTemplate": "de ${0} à ${1}",
	
	"statusTipHeaderColumn": "Colonne",
	"statusTipHeaderCondition": "Règles",
	"statusTipTitle": "Barre de filtre",
	"statusTipMsg": "Cliquer sur la barre de filtre ici pour filtrer sur les valeurs de ${0}.",
	"anycolumn": "n'importe quelle colonne",
	"statusTipTitleNoFilter": "Barre de filtre",
	"statusTipTitleHasFilter": "Filtrer",
	"statusTipRelPre": "Satisfaire",
	"statusTipRelPost": "règles.",
	
	"defaultItemsName": "éléments",
	"filterBarMsgHasFilterTemplate": "${0} sur ${1} ${2} affichés.",
	"filterBarMsgNoFilterTemplate": "Aucun filtre appliqué",
	
	"filterBarDefButton": "Définir le filtre",
	"waiFilterBarDefButton": "Filtrer le tableau",
	"a11yFilterBarDefButton": "Filtrer...",
	"filterBarClearButton": "Effacer le filtre",
	"waiFilterBarClearButton": "Effacer le filtre",
	"closeFilterBarBtn": "Fermer la barre de filtre",
	
	"clearFilterMsg": "Cela supprimera le filtre et affichera tous les enregistrements disponibles.",
	"anyColumnOption": "N'importe quelle colonne",
	
	"trueLabel": "Vrai",
	"falseLabel": "Faux"
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dojox/grid/enhanced/nls/fr/Filter.js <==
define(
//begin v1.x content
({
	"clearFilterDialogTitle": "Effacer le filtre",
	"filterDefDialogTitle": "Filtrer",
	"ruleTitleTemplate": "Règle ${0}",
	
	"conditionEqual": "égal",
	"conditionNotEqual": "est différent de",
	"conditionLess": "est inférieur à",
	"conditionLessEqual": "inférieur ou égal",
	"conditionLarger": "est supérieur à",
	"conditionLargerEqual": "supérieur ou égal",
	"conditionContains": "contient",
	"conditionIs": "est",
	"conditionStartsWith": "commence par",
	"conditionEndWith": "se termine par",
	"conditionNotContain": "ne contient pas",
	"conditionIsNot": "n'est pas",
	"conditionNotStartWith": "ne commence pas par",
	"conditionNotEndWith": "ne se termine pas par",
	"conditionBefore": "avant",
	"conditionAfter": "après",
	"conditionRange": "plage",
	"conditionIsEmpty": "est vide",
	
	"all": "tout",
	"any": "n'importe quelle",
	"relationAll": "toutes les règles",
	"waiRelAll": "Satisfaire à toutes les règles suivantes :",
	"relationAny": "n'importe quelles règles",
	"waiRelAny": "Satisfaire à une quelconque des règles suivantes :",
	"relationMsgFront": "Satisfaire",
	"relationMsgTail": "",
	"and": "et",
	"or": "ou",
	
	"addRuleButton": "Ajouter une règle",
	"waiAddRuleButton": "Ajouter une nouvelle règle",
	"removeRuleButton": "Supprimer la règle",
	"waiRemoveRuleButtonTemplate": "Supprimer la règle ${0}",
	
	"cancelButton": "Annuler",
	"waiCancelButton": "Annuler cette boîte de dialogue",
	"clearButton": "Effacer",
	"waiClearButton": "Effacer le filtre",
	"filterButton": "Filtrer",
	"waiFilterButton": "Soumettre le filtre",
	
	"columnSelectLabel": "Colonne",
	"waiColumnSelectTemplate": "Colonne pour la règle ${0}",
	"conditionSelectLabel": "Condition",
	"waiConditionSelectTemplate": "Condition pour la règle ${0}",
	"valueBoxLabel": "Valeur",
	"waiValueBoxTemplate": "Saisir la valeur à filtrer pour la règle ${0}",
	
	"rangeTo": "à",
	"rangeTemplate": "de ${0} à ${1}",
	
	"statusTipHeaderColumn": "Colonne",
	"statusTipHeaderCondition": "Règles",
	"statusTipTitle": "Barre de filtre",
	"statusTipMsg": "Cliquer sur la barre de filtre ici pour filtrer sur les valeurs de ${0}.",
	"anycolumn": "n'importe quelle colonne",
	"statusTipTitleNoFilter": "Barre de filtre",
	"statusTipTitleHasFilter": "Filtrer",
	"statusTipRelAny": "Répondre à l'une des règles.",
	"statusTipRelAll": "Réponde à toutes les régles.",
	
	"defaultItemsName": "éléments",
	"filterBarMsgHasFilterTemplate": "${0} sur ${1} ${2} affichés.",
	"filterBarMsgNoFilterTemplate": "Aucun filtre appliqué",
	
	"filterBarDefButton": "Définir le filtre",
	"waiFilterBarDefButton": "Filtrer le tableau",
	"a11yFilterBarDefButton": "Filtrer...",
	"filterBarClearButton": "Effacer le filtre",
	"waiFilterBarClearButton": "Effacer le filtre",
	"closeFilterBarBtn": "Fermer la barre de filtre",
	
	"clearFilterMsg": "Cela supprimera le filtre et affichera tous les enregistrements disponibles.",
	"anyColumnOption": "N'importe quelle colonne",
	
	"trueLabel": "Vrai",
	"falseLabel": "Faux"
})
//end v1.x content
);
